package com.isu.gaswellwatch.dao;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.entity.Block;
import com.isu.gaswellwatch.vo.BlockVO;
import org.apache.ibatis.annotations.Mapper;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;

/**
 * 区块Mapper接口
 *
 * @author scwsl
 * @date 2024-11-17
 */
@Mapper
@Repository
public interface BlockDao extends BaseMapper<Block> {
    /**
     * 查询区块
     *
     * @param id 区块主键
     * @return 区块
     */
    Block selectBlockById(Long id);

    /**
     * 查询区块列表
     *
     * @return 区块集合
     */
    List<BlockVO> selectBlockList(Long departmentId);

    /**
     * 分页查询区块列表
     *
     * @param page 分页信息
     * @param name 区块名称
     * @return 区块
     */
    Page<BlockVO> pageForQuery(Page<BlockVO> page, String name);

    /**
     * 新增区块
     *
     * @param block 区块
     * @return 结果
     */
    int insertBlock(Block block);

    /**
     * 修改区块
     *
     * @param block 区块
     * @return 结果
     */
    int updateBlock(Block block);

    /**
     * 删除区块
     *
     * @param id 区块主键
     * @return 结果
     */
    int deleteBlockById(Long id);

    /**
     * 批量删除区块
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBlockByIds(Collection<Long> ids);

}
